@@ -31,6 +31,7 @@ class TerminalWindow(ScrollText):
     testtab:str=""
     lastlno:int=0
     lastproperty:str=""
+    sendEntry:Entry = None
 
     ColorTable = (
         "#000000",
@@ -327,17 +328,17 @@ class TerminalWindow(ScrollText):
         super().__init__(parent, **kwargs)
         self.bottom = Frame(self, bg="LightGray")
         self.bottom.pack(side=BOTTOM, fill=X)
-        self.sendbtn = Button(self.bottom, text="Snd", command=self.doSend)
+        self.sendbtn = Button(self.bottom, text="Snd", command=self.doSend, font=self.normalfont)
         self.mytext = StringVar()
-        self.sendEntry = Entry(self.bottom, textvariable=self.mytext)
+        self.sendEntry = Entry(self.bottom, textvariable=self.mytext, font=self.fontctl)
         self.sendbtn.pack(side=RIGHT)
         self.sendEntry.pack(fill=X, expand=True)
-        self.sendEntry.bind("<Return>",self.doSendEvent)
+        self.sendEntry.bind("<Return>",self.doSend)
         self.sendEntry.bind("<Up>", self.history)
         self.sendEntry.bind("<Down>", self.history)
         self.textbox.bind("<Double-Button-1>",self.dblClick)
         self.textbox.configure(exportselection=False,inactiveselectbackground=self.textbox["selectbackground"])
-
+        self.textbox.bind("<KeyPress>",self.doRefocus)
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
         self.iscsi = False
@@ -368,6 +369,12 @@ class TerminalWindow(ScrollText):
                     self.historylst.append(value)
             self.historyidx=-1
 
+    def setFontSize(self,newsize:int):
+        super().setFontSize(newsize)
+        if self.sendEntry:
+            self.sendEntry.configure(font=self.fontctl)
+
+
     def dblClick(self,event:Event):
         """Respond to double click"""
         self.gotoError(self.textbox)
@@ -385,6 +392,16 @@ class TerminalWindow(ScrollText):
             self.textbox.tag_raise(SEL) # Make sure selection overrides.
         self.currenttag = tagname
     
+    def doRefocus(self,event:Event):
+        if len(event.char)>0 and event.char.isprintable():
+            self.sendEntry.focus()
+            self.mytext.set(self.mytext.get()+event.char)
+            self.sendEntry.icursor(END)
+            return "break"
+        elif event.keysym=="Return":
+            self.doSend(event)
+            return "break"
+
     def parseVerb(self,value):
         """Return (obj,verb), or False if not valid."""
         if value.startswith('@'):
@@ -975,18 +992,15 @@ class TerminalWindow(ScrollText):
             self.sendCmd(page.textbox.get("1.0","end"))
             self.onExamineLine=self.doCheckCompile
 
-    def doSend(self):
+    def doSend(self,event:Event=None):
         s = self.mytext.get()
-        print("Send:", s)
         self.mytext.set("")
         if self.socket != None:
             self.socket.send((s + "\n").encode("utf-8"))
             self.historylst.insert(0,s)
             self.historyidx=-1
+        self.sendEntry.focus()
 
-    def doSendEvent(self,event):
-        self.doSend()
-        
     def doConnect(self, server, port):
         self.disconnect()
         self.sendtext("Connecting to %s %d\n" % (server,port))
